@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# go.rb $Revision: 1.1.1.1 $
+# go.rb $Revision: 1.4 $
 #
 # Copyright (C) 2004  Michitaka Ohno <elpeo@mars.dti.ne.jp>
 #
@@ -18,16 +18,21 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+# Inspired by a discussion of following URL:
+# http://mput.dip.jp/mput/?date=20040316#p05
+
+BEGIN { $defout.binmode }
+
 require 'cgi'
 
 if ENV['PATH_INFO'] then
-	url = ENV['PATH_INFO'].split( /\//, 3 )[2].sub(/^http:\/+/, 'http://' )
+	url = ENV['PATH_INFO'].split( /\//, 3 )[2].sub( /^http:\/+/, 'http://' )
 	if ENV['QUERY_STRING'] && ENV['QUERY_STRING'] != "" then
 		url << '?' + ENV['QUERY_STRING']
 	end
 else
 	require File.expand_path( 'antenna.rb', File::dirname( __FILE__ ) )
-	url = Antenna.new.instance_eval( "@antenna_url" )
+	url = Antenna.new.antenna_url
 end
 
 print CGI.new.header( {"status" => "REDIRECT", "Location" => url} ) 
