@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# update.rb $Revision: 1.1.1.1 $
+# update.rb $Revision: 1.3 $
 #
 # Copyright (C) 2004  Michitaka Ohno <elpeo@mars.dti.ne.jp>
 #
@@ -18,11 +18,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+BEGIN { $defout.binmode }
+
 require File.expand_path( 'antenna.rb', File::dirname( __FILE__ ) )
 
 if ENV['REQUEST_METHOD'] then
 	require 'cgi'
-	path = Antenna.new.instance_eval( "@antenna_url" )
+	path = Antenna.new.antenna_url
 	print CGI.new.header( {'type' => 'text/html'} )
 	print <<-HTML
 	<html>
@@ -38,3 +40,4 @@ else
 	a.go_round
 	a.output
 end
+
